"""
In this module, we provide several examples for how various neuron models
are implemented in the ``NumpyBrain`` framework. For each neuron model,
one of the most important elements is ``update_state()`` function.
"""

# HH_model.py
from npbrain.neurons.HH_model import *

# input_model.py
from npbrain.neurons.input_model import *

# Izhikevich_model.py
from npbrain.neurons.Izhikevich_model import *

# LIF_model.py
from npbrain.neurons.LIF_model import *

